# shellcode
![shellcode logo](https://raw.githubusercontent.com/4thel00z/shellcode/master/logo.png)

## Motivation

In the course of pawning n00bs often the need arises to introspect some (generated) shellcode or check
it for sanity.

This tools does exactly that.

## Usage
```
echo "<some shellcode>" | python3 -m shellcode 
```

## License

This project is licensed under the GPL-3 license.
